"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ezSpawn = require("ez-spawn");
const fs_1 = require("./fs");
const manifest_1 = require("./manifest");
/**
 * Runs the specified NPM script in the package.json file.
 */
async function runNpmScript(script, operation) {
    let { cwd } = operation.options;
    let { data: manifest } = await fs_1.readJsonFile("package.json", cwd);
    if (manifest_1.isManifest(manifest) && hasScript(manifest, script)) {
        await ezSpawn.async("npm", ["run", script, "--silent"], { stdio: "inherit" });
        operation.update({ event: "npm script" /* NpmScript */, script });
    }
    return operation;
}
exports.runNpmScript = runNpmScript;
/**
 * Determines whether the specified NPM script exists in the given manifest.
 */
function hasScript(manifest, script) {
    let scripts = manifest.scripts;
    if (scripts && typeof scripts === "object") {
        return Boolean(scripts[script]);
    }
    return false;
}
//# sourceMappingURL=run-npm-script.js.map